@@ -1,11 +1,13 @@
 /* Capstone Disassembly Engine */
-/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2015 */
+/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */
 
 #ifndef CS_ARM64_MAP_H
 #define CS_ARM64_MAP_H
 
 #include "capstone/capstone.h"
 
+#define ARR_SIZE(a) (sizeof(a)/sizeof(a[0]))
+
 // return name of regiser in friendly string
 const char *AArch64_reg_name(csh handle, unsigned int reg);
 
@@ -17,22 +19,22 @@ const char *AArch64_insn_name(csh handle, unsigned int id);
 const char *AArch64_group_name(csh handle, unsigned int id);
 
 // map instruction name to public instruction ID
-arm64_reg AArch64_map_insn(const char *name);
+arm64_insn AArch64_map_insn(const char *name);
 
 // map internal vregister to public register
 arm64_reg AArch64_map_vregister(unsigned int r);
 
+arm64_sys_op AArch64_map_sys_op(const char *name);
+
 void arm64_op_addReg(MCInst *MI, int reg);
 
 void arm64_op_addVectorArrSpecifier(MCInst * MI, int sp);
 
-void arm64_op_addVectorElementSizeSpecifier(MCInst * MI, int sp);
-
 void arm64_op_addFP(MCInst *MI, float fp);
 
 void arm64_op_addImm(MCInst *MI, int64_t imm);
 
-uint8_t *AArch64_get_op_access(cs_struct *h, unsigned int id);
+const uint8_t *AArch64_get_op_access(cs_struct *h, unsigned int id);
 
 void AArch64_reg_access(const cs_insn *insn,
 		cs_regs regs_read, uint8_t *regs_read_count,
