@@ -600,7 +600,7 @@ bool TMS320C64x_getInstruction(csh ud, const uint8_t *code, size_t code_len,
 	if(MI->flat_insn->detail)
 		memset(MI->flat_insn->detail, 0, offsetof(cs_detail, tms320c64x)+sizeof(cs_tms320c64x));
 
-	insn = (code[3] << 0) | (code[2] << 8) | (code[1] << 16) | ((uint32_t) code[0] << 24);
+	insn = readBytes32(MI, code);
 	result = decodeInstruction_4(DecoderTable32, MI, insn, address, info, 0);
 
 	if(result == MCDisassembler_Success) {
