@@ -1,4 +1,4 @@
 # CS_ARCH_MIPS, CS_MODE_MIPS32+CS_MODE_BIG_ENDIAN, None
 0x79,0x03,0xed,0xd9 = insert.b $w23[3], $sp
-0x79,0x22,0x2d,0x19 = insert.h $w20[2], $5
-0x79,0x32,0x7a,0x19 = insert.w $w8[2], $15
+0x79,0x22,0x2d,0x19 = insert.h $w20[2], $a1
+0x79,0x32,0x7a,0x19 = insert.w $w8[2], $t7
