@@ -75,12 +75,12 @@
 0xc5,0x19,0x15,0x7c,0xcb,0xfc = vunpckhpd -4(%rbx, %rcx, 8), %xmm12, %xmm15
 0xc5,0x18,0x14,0x7c,0xcb,0xfc = vunpcklps -4(%rbx, %rcx, 8), %xmm12, %xmm15
 0xc5,0x19,0x14,0x7c,0xcb,0xfc = vunpcklpd -4(%rbx, %rcx, 8), %xmm12, %xmm15
-0xc4,0x41,0x18,0xc2,0xfa,0x00 = vcmpps $0, %xmm10, %xmm12, %xmm15
-0xc5,0x18,0xc2,0x38,0x00 = vcmpps $0, (%rax), %xmm12, %xmm15
-0xc4,0x41,0x18,0xc2,0xfa,0x07 = vcmpps $7, %xmm10, %xmm12, %xmm15
-0xc4,0x41,0x19,0xc2,0xfa,0x00 = vcmppd $0, %xmm10, %xmm12, %xmm15
-0xc5,0x19,0xc2,0x38,0x00 = vcmppd $0, (%rax), %xmm12, %xmm15
-0xc4,0x41,0x19,0xc2,0xfa,0x07 = vcmppd $7, %xmm10, %xmm12, %xmm15
+0xc4,0x41,0x18,0xc2,0xfa,0x00 = vcmpeqps %xmm10, %xmm12, %xmm15
+0xc5,0x18,0xc2,0x38,0x00 = vcmpeqps (%rax), %xmm12, %xmm15
+0xc4,0x41,0x18,0xc2,0xfa,0x07 = vcmpordps %xmm10, %xmm12, %xmm15
+0xc4,0x41,0x19,0xc2,0xfa,0x00 = vcmpeqpd %xmm10, %xmm12, %xmm15
+0xc5,0x19,0xc2,0x38,0x00 = vcmpeqpd (%rax), %xmm12, %xmm15
+0xc4,0x41,0x19,0xc2,0xfa,0x07 = vcmpordpd %xmm10, %xmm12, %xmm15
 0xc4,0x41,0x18,0xc6,0xeb,0x08 = vshufps $8, %xmm11, %xmm12, %xmm13
 0xc5,0x18,0xc6,0x6c,0xcb,0xfc,0x08 = vshufps $8, -4(%rbx, %rcx, 8), %xmm12, %xmm13
 0xc4,0x41,0x19,0xc6,0xeb,0x08 = vshufpd $8, %xmm11, %xmm12, %xmm13
@@ -388,7 +388,7 @@
 0xc4,0x41,0x12,0x5a,0xd4 = vcvtss2sd %xmm12, %xmm13, %xmm10
 0xc5,0x12,0x5a,0x10 = vcvtss2sd (%rax), %xmm13, %xmm10
 0xc4,0x41,0x78,0x5b,0xd5 = vcvtdq2ps %xmm13, %xmm10
-0xc5,0x78,0x5b,0x29 = vcvtdq2ps (%ecx), %xmm13
+0xc5,0x78,0x5b,0x29 = vcvtdq2ps (%rcx), %xmm13
 0xc4,0x41,0x7a,0x5b,0xdc = vcvttps2dq %xmm12, %xmm11
 0xc5,0x7a,0x5b,0x18 = vcvttps2dq (%rax), %xmm11
 0xc4,0x41,0x78,0x5a,0xdc = vcvtps2pd %xmm12, %xmm11
@@ -552,8 +552,8 @@
 0xc5,0x79,0x6e,0xf0 = vmovd %eax, %xmm14
 0xc5,0x79,0x6e,0x30 = vmovd (%rax), %xmm14
 0xc5,0x79,0x7e,0x30 = vmovd %xmm14, (%rax)
-0xc4,0x61,0xf9,0x6e,0xf0 = vmovd %rax, %xmm14
-0xc4,0xe1,0xf9,0x7e,0xc0 = vmovd %xmm0, %rax
+0xc4,0x61,0xf9,0x6e,0xf0 = vmovq %rax, %xmm14
+0xc4,0xe1,0xf9,0x7e,0xc0 = vmovq %xmm0, %rax
 0xc5,0x79,0xd6,0x30 = vmovq %xmm14, (%rax)
 0xc4,0x41,0x7a,0x7e,0xe6 = vmovq %xmm14, %xmm12
 0xc5,0x7a,0x7e,0x30 = vmovq (%rax), %xmm14
@@ -842,19 +842,19 @@
 0xc5,0x7e,0x5b,0x10 = vcvttps2dq (%rax), %ymm10
 0xc4,0x41,0x79,0xe6,0xd3 = vcvttpd2dq %xmm11, %xmm10
 0xc4,0x41,0x7d,0xe6,0xd4 = vcvttpd2dq %ymm12, %xmm10
-0xc4,0x41,0x79,0xe6,0xd3 = vcvttpd2dqx %xmm11, %xmm10
+0xc4,0x41,0x79,0xe6,0xd3 = vcvttpd2dq %xmm11, %xmm10
 0xc5,0x79,0xe6,0x18 = vcvttpd2dqx (%rax), %xmm11
-0xc4,0x41,0x7d,0xe6,0xdc = vcvttpd2dqy %ymm12, %xmm11
+0xc4,0x41,0x7d,0xe6,0xdc = vcvttpd2dq %ymm12, %xmm11
 0xc5,0x7d,0xe6,0x18 = vcvttpd2dqy (%rax), %xmm11
 0xc4,0x41,0x7d,0x5a,0xd4 = vcvtpd2ps %ymm12, %xmm10
-0xc4,0x41,0x79,0x5a,0xd3 = vcvtpd2psx %xmm11, %xmm10
+0xc4,0x41,0x79,0x5a,0xd3 = vcvtpd2ps %xmm11, %xmm10
 0xc5,0x79,0x5a,0x18 = vcvtpd2psx (%rax), %xmm11
-0xc4,0x41,0x7d,0x5a,0xdc = vcvtpd2psy %ymm12, %xmm11
+0xc4,0x41,0x7d,0x5a,0xdc = vcvtpd2ps %ymm12, %xmm11
 0xc5,0x7d,0x5a,0x18 = vcvtpd2psy (%rax), %xmm11
 0xc4,0x41,0x7f,0xe6,0xd4 = vcvtpd2dq %ymm12, %xmm10
-0xc4,0x41,0x7f,0xe6,0xdc = vcvtpd2dqy %ymm12, %xmm11
+0xc4,0x41,0x7f,0xe6,0xdc = vcvtpd2dq %ymm12, %xmm11
 0xc5,0x7f,0xe6,0x18 = vcvtpd2dqy (%rax), %xmm11
-0xc4,0x41,0x7b,0xe6,0xd3 = vcvtpd2dqx %xmm11, %xmm10
+0xc4,0x41,0x7b,0xe6,0xd3 = vcvtpd2dq %xmm11, %xmm10
 0xc5,0x7b,0xe6,0x18 = vcvtpd2dqx (%rax), %xmm11
 0xc4,0x41,0x1c,0xc2,0xeb,0x00 = vcmpeqps %ymm11, %ymm12, %ymm13
 0xc4,0x41,0x1c,0xc2,0xeb,0x02 = vcmpleps %ymm11, %ymm12, %ymm13
@@ -1009,9 +1009,9 @@
 0xc4,0x42,0x7d,0x0e,0xd4 = vtestps %ymm12, %ymm10
 0xc4,0x62,0x79,0x0e,0x20 = vtestps (%rax), %xmm12
 0xc4,0x62,0x7d,0x0e,0x20 = vtestps (%rax), %ymm12
-0xc4,0x43,0x79,0x17,0xc0,0x0a = vextractps $10, %xmm8, %r8
+0xc4,0x43,0x79,0x17,0xc0,0x0a = vextractps $10, %xmm8, %r8d
 0xc4,0xe3,0x79,0x17,0xe1,0x07 = vextractps $7, %xmm4, %ecx
-0xc4,0xe1,0xf9,0x7e,0xe1 = vmovd %xmm4, %rcx
+0xc4,0xe1,0xf9,0x7e,0xe1 = vmovq %xmm4, %rcx
 0xc5,0xf9,0x50,0xcc = vmovmskpd %xmm4, %ecx
 0xc5,0xfd,0x50,0xcc = vmovmskpd %ymm4, %ecx
 0xc5,0xf8,0x50,0xcc = vmovmskps %xmm4, %ecx
